'use strict';
var lrSnippet = require('grunt-contrib-livereload/lib/utils').livereloadSnippet;
var mountFolder = function (connect, dir) {
  return connect.static(require('path').resolve(dir));
};


module.exports = function (grunt) {
  require('matchdep').filterDev('grunt-*').forEach(grunt.loadNpmTasks);
  grunt.initConfig({
    jshint: {
      options: {
        jshintrc: '.jshintrc'
      },
      all: [
        'Gruntfile.js',
        'app/js/{,*/}*.js',
        '!app/vendor/*',
        'test/spec/{,*/}*.js'
      ]
    },

    connect: {
      options:{
        port:9000,
        hostname: '0.0.0.0'
      },
      livereload:{
        options:{

          middleware: function(connect) {
            return [lrSnippet, 

              mountFolder(connect, 'app')];
          }
        }
      }
    },
    clean: {
      dist: {
        files: [{
          dot: true,
          src: ['dist']
        }]
      }
    },

    cssmin: {
      dist: {
        files: {
          'dist/styles/main.css': ['app/styles/{,*/}*.css']
        }
      }
    },
    copy: {
      dist: {
        files: [{
          expand: true,
          dot: true,
          cwd: 'app',
          dest: 'dist',
          src: [
            '*.{ico,txt}',
            '*.html',
            'vendor/requirejs/require.js',
            '.htaccess',
            'images/{,*/}*.{webp,gif}',
            'styles/fonts/*'
          ]
        }]
      }
    },
        // Configuration to be run (and then tested)
    regarde: {
      less: {
        files: 'app/styles/*.less',
        tasks:['less']
      },

      livereload: {
        files: ['app/**/*.js', 'app/**/*.html', 'app/**/*.css'],
        tasks: ['livereload']
      }
    },
    requirejs: {
      compile: {
        options: {
          name:'app',
          baseUrl: "app/js/",
          mainConfigFile: "app/js/main.js",
          out: "dist/js/main.js",
          stubModules: ['text', 'bar']
        }
      }
    },

    less: {
      dev: {
        files: [{
          expand: true,     // Enable dynamic expansion.
          cwd: 'app/styles/',      // Src matches are relative to this path.
          src: ['**/*.less'], // Actual pattern(s) to match.
          dest: 'app/styles/',   // Destination path prefix.
          ext: '.css'   // Dest filepaths will have this extension.
        }]
      },
      dist: {
        options: {
          yuicompress: true
        },
        files: [{
          expand: true,     // Enable dynamic expansion.
          cwd: 'app/styles/',      // Src matches are relative to this path.
          src: ['**/*.less'], // Actual pattern(s) to match.
          dest: 'app/styles/',   // Destination path prefix.
          ext: '.css'   // Dest filepaths will have this extension.
        }]
      }
    },
    build:{}
  });

    grunt.registerTask('build', [
    'clean:dist',
//    'useminPrepare',
//    'concurrent:dist',
    'requirejs',
    'cssmin',

    'copy',
//    'rev',
//    'usemin'
  ]);
  grunt.registerTask('default', ['livereload-start', 'less:dev', 'connect', 'regarde']);
};